<?php
/*
 * Plugin Name: CashBill Payment Gateway for Jigoshop
 * Plugin URL: http://cashbill.pl
 * Description: CashBill is easy to use electronic payment system. You can integrate our payment package with your website and offer customers secure payments.
 * Version: 1.0.1
 * Author: Łukasz Firek
 */


function cashbill_gateway() {
	
	if ( !class_exists( 'jigoshop_payment_gateway' ) ) return;
	

	add_filter('jigoshop_payment_gateways', function ($methods){
			$methods[] = 'cashbill';
		
			return $methods;
		},0);
	
	class cashbill extends jigoshop_payment_gateway
	{
		
		public function __construct()
		{
			parent::__construct();

			$options = Jigoshop_Base::get_options();

			$this->id = 'cashbill';
			$this->icon = "";
			$this->has_fields = false;
			$this->enabled = $options->get('jigoshop_cashbill_enabled');
			$this->title = $options->get('jigoshop_cashbill_title');
			$this->description = $options->get('jigoshop_cashbill_description');
			$this->paymentPointId = $options->get('jigoshop_cashbill_id');
			$this->paymentPointKey = $options->get('jigoshop_cashbill_key');
			$this->testmode = $options->get('jigoshop_cashbill_testmode');
			$this->paymentButton = $options->get('jigoshop_cashbill_button');
			$this->paymentDescription = $options->get('jigoshop_cashbill_payment_description');
			
			$this->decimals = 2;

			$this->liveurl = 'https://pay.cashbill.pl/ws/rest/';
			$this->testurl = 'https://pay.cashbill.pl/testws/rest/';

			add_action('receipt_cashbill', array($this, 'receipt_page'));

			add_action('init', array($this, 'cashbill_callback'));
		}

	function payment_fields()
	{
		if ($this->description) {
			echo wpautop(wptexturize($this->description));
		}
	}

	function process_payment($order_id)
	{
		$order = new jigoshop_order($order_id);

		return array(
			'result' => 'success',
			'redirect' => add_query_arg('order', $order->id, add_query_arg('key', $order->order_key, get_permalink(jigoshop_get_page_id('pay'))))
		);
	}

	function receipt_page($order)
	{
		echo '<p>'.$this->paymentDescription.'</p>';
		echo $this->generate_cashbill_form($order);
	}

	public function generate_cashbill_form($order_id)
	{
		$order = new jigoshop_order($order_id);

		if ($this->testmode == 'yes') {
			$url = $this->testurl;
		} else {
			$url = $this->liveurl;
		}

		$checkout_redirect = apply_filters('jigoshop_get_checkout_redirect_page_id', jigoshop_get_page_id('thanks'));

		$cashbill_args = array(
				'title'=>"Zamówienie nr : ".$order->get_order_number(),
				'amount.value'=>number_format((float)$order->order_total, $this->decimals),
				'amount.currencyCode'=>Jigoshop_Base::get_options()->get('jigoshop_currency'),
				'returnUrl'=>add_query_arg('key', $order->order_key, add_query_arg('order', $order_id, get_permalink($checkout_redirect))),
				'description'=>"Płatność za zamówienie o numerze ".$order->get_order_number(),
				'negativeReturnUrl'=>$order->get_cancel_order_url(),
				'additionalData'=>$order_id,
				'referer'=>"jigoshop",
				'personalData.firstName'=>$order->billing_first_name,
				'personalData.surname'=>$order->billing_last_name,
				'personalData.email'=>$order->billing_email,
				'personalData.country'=>$order->billing_country,
				'personalData.city'=>$order->billing_city,
				'personalData.postcode'=>$order->billing_postcode,
				'personalData.street'=>$order->billing_address_1.$order->billing_address_2
		);
		
		$sign = SHA1(implode("",$cashbill_args).$this->paymentPointKey);
		$cashbill_args['sign'] = $sign;
		
		$response = wp_remote_post( $url.'payment/'.$this->paymentPointId, array(
				'method'    => 'POST',
				'timeout'   => 90,
				'body' => $cashbill_args,
				'sslverify' => false,
		) );
		
		$response = json_decode($response['body']);

		
		
		return '<form action="'.$response->redirectUrl.'" method="get" id="cashbill_payment_form">
						<input type="submit" class="button-alt" id="cashbill_payment_form" value="'.$this->paymentButton.'" />
						<script type="text/javascript">
							(function($){
								$(document).ready(function(){
									$("#cashbill_payment_form").click();
								})
							})(jQuery);
						</script>
						</form>';
	}
		function cashbill_callback() {
			global $wpdb;
			if (isset ( $_GET ['cmd'] ) && isset ( $_GET ['args'] ) && isset ( $_GET ['sign'] )) {
				
				if (md5 ( $_GET ['cmd'] . $_GET ['args'] . $this->paymentPointKey ) == $_GET ['sign']) {
					if ($this->testmode == 'yes') {
						$url = $this->testurl;
					} else {
						$url = $this->liveurl;
					}
					
					$signature = SHA1 ( $_GET ['args'] . $this->paymentPointKey );
					$response = wp_remote_get ( $url . 'payment/' . $this->paymentPointId . '/' . $_GET ['args'] . '?sign=' . $signature );
					$response = json_decode ( $response ['body'] );
					
					$order = new jigoshop_order ( ( int ) $response->additionalData );
					if ($order->status != 'completed') {
						
						if ($response->status == 'PositiveFinish') {
							
							$order->add_order_note ( "Zamówienie zostało poprawnie opłacone poprzez płatności CashBill." );
							$order->payment_complete ();
							
							jigoshop_log ( 'CashBill: płatność została wykonana dla zamówienia numer: ' . $_GET ['args'] );
						}elseif ($response->status == 'Abort' || $response->status == 'Fraud' || $response->status == 'NegativeFinish') {
							$order->update_status ( 'failed', sprintf ( 'Status płatności CashBill :  %s.', $response->status ) );
							jigoshop_log ( "CashBill: błędne płatność ze statusem = " . $response->status . " dla zamówienia numer : " . $_GET ['args'] );
						}
					}
					echo 'OK';
				} else {
					echo "BLAD SYGNATURY";
				}
				exit ();
			}
		}
	
	public function process_gateway($subtotal, $shipping_total, $discount = 0)
	{
		
		if (!(isset($subtotal) && isset($shipping_total))) {
			return false;
		}

		return true;
	}

	protected function get_default_options()
	{
		return array(
			array(
				'name' => sprintf('Płatności CashBill %s', '<img style="vertical-align:middle;margin-top:-4px;margin-left:10px;" src="'.plugins_url( 'img/cashbill_100x39.png', __FILE__ ).'" alt="CashBill" /> <a href="'.plugins_url( 'pdf/Instrukcja instalacji.pdf', __FILE__ ).'" target="_blank"><img src="'.plugins_url( 'img/pdf-icon.png', __FILE__ ).'" /> Instrukcja Instalacji</a>'),
				'type' => 'title',
			),
			array(
				'name' => "Włącz Płatności CashBill",
				'desc' => '',
				'tip' => '',
				'id' => 'jigoshop_cashbill_enabled',
				'std' => 'yes',
				'type' => 'checkbox',
				'choices' => array(
					'no' => __('No', 'jigoshop'),
					'yes' => __('Yes', 'jigoshop')
				)
			),
			array(
				'name' => "Tryb Testowy",
				'desc' => "Włącz tryb testowy umożliwiający wykonanie testowych płatności.",
				'tip' => '',
				'id' => 'jigoshop_cashbill_testmode',
				'std' => 'no',
				'type' => 'checkbox',
				'choices' => array(
					'no' => __('No', 'jigoshop'),
					'yes' => __('Yes', 'jigoshop')
				)
			),
			array(
				'name' => "Tytuł metody",
				'desc' => '',
				'tip' => "Tytuł, który widzi użytkownik podczas realizacji transakcji.",
				'id' => 'jigoshop_cashbill_title',
				'std' => "Płatności CashBill",
				'type' => 'text'
			),
			array(
				'name' => "Opis metody",
				'desc' => '',
				'tip' => "Wiadomośc, którą widzi użytkownik podczas realizacji transakcji.",
				'id' => 'jigoshop_cashbill_description',
				'std' => "Zapłać za pomocą szybkich płatności CashBill",
				'type' => 'longtext'
			),
			array(
				'name' => "Identyfikator punktu płatności",
				'desc' => '',
				'tip' => "Identyfikator nadawany przy zakładaniu nowego punktu płatności na stronie cashbill.pl .",
				'id' => 'jigoshop_cashbill_id',
				'std' => '',
				'type' => 'text'
			),
			array(
				'name' => "Klucz punktu płatności",
				'desc' => '',
				'tip' => "Klucz nadawany przy zakładaniu nowego punktu płatności na stronie cashbill.pl .",
				'id' => 'jigoshop_cashbill_key',
				'std' => '',
				'type' => 'text'
				),
		    array(
				'name' => "Przycisk przekierowania do płatności",
				'desc' => '',
				'tip' => "Informacja znajdująca się na przycisku przekierowującym do dokonania płatności .",
				'id' => 'jigoshop_cashbill_button',
				'std' => 'Zamówienie z obowiązkiem zapłaty',
				'type' => 'text'
			),
			array(
				'name' => "Informacja po złożeniu zamówienia",
				'desc' => '',
				'tip' => "Informacja znajdująca się na stronie przed przekierowaniem użytkownika na stronę płatności.",
				'id' => 'jigoshop_cashbill_payment_description',
				'std' => "Dziękujemy za zakup w naszym sklepie internetowym. Płatność może zostać zrealizowana po kliknięciu w poniższy przycisk. Sklep automatycznie dostanie informację o wpłaconej kwocie.",
				'type' => 'longtext'
			),
		);
	}
}

}

add_action( 'plugins_loaded', 'cashbill_gateway', 0 );
